# Passholder
TUI program for storage passwords in encrypted file.

<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple example steps.

### Prerequisites
gnupg
* macOS
  Install HomeBrew by entering the following in the command line:
  ```sh
  /usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
  ```
  Install GnuPG by entering the following in the command line:
  ```sh
  brew install gnupg
  ```
  You may be asked to enter Xcode in the command line if you never installed it.
  Debian OS (Linux) - Install GnuPG by entering the following in the command line:

  ```sh
  apt install gnupg
  ```
  Ubuntu OS (Linux) - Install GnuPG by entering the following in the command line:

  ```sh
  apt-get install gnupg
  ```
  Redhat OS (Linux) - Install GnuPG by entering the following in the command line:
  ```sh
  yum install gnupg
  ```


### Installation
```sh
pip install passholder
```

<!-- USAGE EXAMPLES -->
## Usage

```sh
passholder
```


<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- LICENSE -->
## License

Distributed under the GPL-v3.0 License. See `LICENSE.txt` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>
